CLEESE is a free, standalone Python module, distributed under an open-source MIT Licence on the FEMTO Neuro team [github page](https://github.com/neuro-team-femto/cleese). 

It was originally designed in 2018 by [Juan José Burred](https://www.jjburred.com), [Emmanuel Ponsot](https://www.stms-lab.fr/person/emmanuel-ponsot) and [Jean-Julien Aucouturier](https://www.femto-st.fr/fr/personnel-femto/jeanaucouturier) at [STMS Lab](https://www.stms-lab.fr) (IRCAM/CNRS/Sorbonne Université, Paris - France), and released on the [IRCAM Forum](https://forum.ircam.fr/) platform. As of 2021, CLEESE is now developed and maintained by the [FEMTO Neuro Team](https://neuro-team-femto.github.io/) at the [FEMTO-ST Institute](https://www.femto-st.fr/) (CNRS/Université Bourgogne Franche-Comté) in Besançon - France, and distributed on the team's [github page](https://github.com/neuro-team-femto/cleese). 

CLEESE's development was originally funded by the [European Research Council](https://erc.europa.eu) ([CREAM](https://neuro-team-femto.github.io/cream/) 335536, 2014-2019, PI: JJ Aucouturier), and has since then received support from [Agence Nationale de la Recherche](https://anr.fr/) (ANR SEPIA, AND Sounds4Coma), [Fondation pour l'Audition](https://www.fondationpourlaudition.org) (DASHES) and [Région Bourgogne-Franche Comté](https://www.bourgognefranchecomte.fr/) (ASPECT). 

## Citing CLEESE

If you use CLEESE in academic work, please cite it as : 

```
Burred, JJ., Ponsot, E., Goupil, L., Liuni, M. & Aucouturier, JJ. (2019).
CLEESE: An open-source audio-transformation toolbox for data-driven experiments in speech and music cognition. 
PLoS one, 14(4), e0205943.
```


## CLEESE contributors: 
* Juan José Burred (original development, Phase Vocoder Engine) :simple-github: [jjburred](https://github.com/jjburred)
* Emmanuel Ponsot (tool specification) 
* JJ Aucouturier (software architecture) :simple-github: [jjau](https://github.com/jjau)
* Lara Kermarec (Face warp engine) :simple-github: [nemirwen](https://github.com/nemirwen)
* Paige Tuttosi (Documentation) :simple-github: [chocobearz](https://github.com/chocobearz)

